*{margin: 0px;padding: 0px;}
ol, ul {list-style: none outside none;}
blockquote, q {quotes: none;}
blockquote:before, blockquote:after, q:before, q:after {content: none;}
:focus {outline: 0 none;}
img{border:0}
a{
    text-decoration: none;
    color: #19485C;
}

a:hover {
    color: #4DA0C6;
}

table {
    margin: 0;padding:0;
    border-right: none;
    border-bottom: none;
    font-size: 14px;
    background: #fff;
    border-spacing:0;
}
td{
    padding: 4px;
    border: none;
    border-bottom: 1px solid #A8A8A8;
    border-right: 1px solid #A8A8A8;
}
td.propertie{padding-left:10px; color:blue;width: 178px;}
.slapvalues{display:block;width: 522px;word-wrap: break-word}
td.first{border-left: 1px solid #A8A8A8;}
th{
    background: #2281C1;
    padding: 6px;
    color: #fff;
    font-weight: normal;
    font-size: 18px;
}
table.small th{padding: 4px;font-size: 16px;}
textarea {
	width:932px;
  font-family: 'Helvetica Neue',Tahoma,Helvetica,Arial,sans-serif;
}

body {
	background: #1E73BD;/*#1862C4 url("../images/1307251316-background-stripes.gif") repeat #9C9C9C;*/
	font-family: 'Helvetica Neue',Tahoma,Helvetica,Arial,sans-serif;
	color: #000000;
	font-size: 13px;
  overflow: -moz-scrollbars-vertical;
overflow-y: scroll;
}

#page
{
	margin: 10px auto;
	width: 1014px;
}

#logo{
	margin-left:60px;
}

#header{
    height: 78px;
    padding-top: 12px;
    width: 1014px;
    background: url(../images/head.png) no-repeat;
}

.block_header{
    text-align: left;
    padding-left: 20px;
    height: 30px;
    position:relative;
}

#header .run{
    margin-right: 30px;
    float: right;
}

#header .info{
    font-size: 16px;
    font-weight: normal;
    padding-top: 3px;
    float: left;
    width: 820px;
    height: 22px;
    text-align: center;
    color: #4c6172;
    text-shadow: 0 1px 1px #fff;
    overflow: hidden;
}
#header .line{
    width:1px;
    border-left: 1px solid #678DAD;
    background: #CAD4DC;
    height: 24px;
    float: left;
    margin-top: 2px;
    margin-right: 5px;
     margin-left:5px
}

#editor {
    margin: 0;
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    }

.wmenu{
  margin: 1px 0 1px 20px;
}

.wmenu ul{
    height: 34px;
    overflow:hidden;
}

.space{
    margin-left: 28px;
}

.wmenu li{
    float:left;
}

.wmenu li .title_software{
    float:left;
    background: url(../images/software.png) left center no-repeat;
    font-size:15px;
    font-weight:bold;
    color:#678dad;
    cursor: default;
    padding:8px;
    padding-left: 20px;
    padding-right: 5px;
    margin-left:4px;
    height: 18px;
    text-shadow:1px 1px 0 #E6EDF2;
}

.wmenu li .title_instance{
    float:left;
    background: url(../images/settings2.png) left center no-repeat;
    font-size:15px;
    font-weight:bold;
    color:#678dad;
    cursor: default;
    padding:8px;
    padding-left: 20px;
    padding-right: 5px;
    height: 20px;
    margin-left:2px;
    text-shadow:1px 1px 0 #E6EDF2;
}

.wmenu ul li.sep{border-right: 1px solid #c2c2c2; min-width:20px; height:34px}
.wmenu ul li a{
    display:block;
    height: 20px;
    Color:#275777;
    /*background: url(../images/sep.png) right center no-repeat;*/
    border-right: 1px solid #c2c2c2;
    /*font-weight:bold;*/
    font-size:15px;
    text-decoration:none;
    padding:7px 10px 7px 10px;
}
.wmenu ul li:last-child a {border: none}

.wmenu ul li a:hover, .wmenu ul li a.active{
    color: #000;/*#0271BF;*/
    background:#c2c2c2;
}

#main
{
    background: url(../images/main_bg_all.png) repeat-y;
    padding-left: 24px;
    padding-right: 24px;
    min-height: 400px;
}

.main_content{
    position:relative;
    width: 99.6%;
    height: 430px;
    margin-top:10px;
    border:1px solid #4c6172;
    overflow:auto;
}

.main_head{
    height: 15px;
    background: url(../images/main_top.png) no-repeat;
    width: 966px;
}

.content{
    background: url(../images/content.png) repeat-y;
    width: 936px;
    padding: 15px;
    padding-top:0;
    padding-bottom:0;
    min-height: 400px;
}

.content h2{
    color: #4c6172;
    font-weight: normal;
    font-size: 18px;
}
.content h2 a{
    text-decoration:none;
    color: #4DA0C6;
}
.content h2 a:hover{
    color: #19485C;
}

.main_foot{
    height: 15px;
    background: url(../images/main_bottom.png) no-repeat;
    width: 966px;
}

#footer{
    height: 35px;
    width: 934px;
    background: url(../images/footer_bg.png) no-repeat;
    padding-left: 40px;
    padding-right: 40px;
    padding-top: 4px;
    text-align: center;
    color: #4c6172;
    text-shadow: 0px 1px 1px #fff;
}
.dsblebutton{color:#9C9C9C; padding: 5px 10px;display: inline;background: #eee;
        font-weight: bold; border:1px solid #000; margin-top:10px;}
.button {
    padding: 5px 10px;
    display: inline;
    background: #eee;
    color: #000;
    cursor: pointer;
    font-weight: bold;
    border:1px solid #000;
    margin-top:10px;
}
.button:hover {
	background-position: 0 center;
	background: #666666;
	color: #fff;
	box-shadow: 1px 1px 1px #888888;
}
.button:active {
  background: #eee;
  color: #000;
}

.focusField{
    border:solid 1px #73A6FF;
    background:#EFF5FF;
    color:#000;
    padding:5px;
    outline:none;
    font: 13px 'Helvetica Neue', Helvetica, Arial, sans-serif;
}
.idleField{
    background:#fff;
    color: #6F6F6F;
    border: solid 1px #678dad;
    padding:5px;
    outline:none;
    font: 13px 'Helvetica Neue', Helvetica, Arial, sans-serif;
}

input[type="radio"], input[type="checkbox"]{
    margin: 4px;
}

.flash{
    margin-left:20px;
    color:#4A131F;
    font-style:italic;
    font-size:14px;
    position:relative;
}

.flashes{
	margin-bottom:10px;
}

.message {
	color:#FF5500;
	line-height:21px;
}

.clear{
    clear: both;
    height:1px;
}

.home_content{

    padding: 15px;
}

#home_box{
    background: none;
    border: 2px solid #87B0D4;
    padding: 0;
    color: #4c6172;
    margin: 20px auto;
    width: 641px;
}

#home_box a{
    color: #475F73;
    cursor: pointer;
    text-decoration: none;
}

#home_box a:hover{
    text-decoration: underline;
}

#home_box h2{
    font-weight: normal;
    font-size: 23px;
    color: #475F73;
}

#home_box p{
    font-size: 13px;
    color: #475F73;
    float: left;
}

#home_box img{
    border: none;
    float: left;
    margin-left: 10px;
}

.inner_box{
    background: none;
    margin: 0;
    display: block;
    padding: 30px 0 30px 0;
}

.inner_box p{
    font-size: 13px;
    float: left;
    width: 450px;
    cursor:default;
    text-align:justify;
}


.lmenu{
    display: block;
    height: 80px;
    margin: 10px 0 10px 45px;
    padding: 10px;
    padding-bottom:15px;
    width: 530px;
    border: 1px solid #678dad;
}

.smaller{margin-left:10px; width: 350px; float:left}
.smaller p{width: 280px;}
.umenu{display: block;margin: 10px 0 10px 45px; width: 147px; float:left;border: 1px solid #678dad;
padding: 10px;height: 80px;padding-bottom:15px;}
.umenu p{font-size: 13px;float: left;width: 77px;cursor:default;}
.lmenu:hover, .smenu:hover, .sright_menu:hover, .smaller:hover, .umenu:hover{
    background: #96b9d7;
}
.smenu{
    display: block;
    height: 80px;
    margin: 0 10px 0 45px;
    padding: 10px;
    padding-bottom:15px;
    width: 250px;
    border: 1px solid #678dad;
    float: left;
}

.sright_menu{
    display: block;
    height: 80px;
    padding: 10px;
    padding-bottom:15px;
    border: #678dad;
    width: 247px;
    border: 1px solid #678dad;
    float: left;
}

.sright_menu p, .smenu p{
    font-size: 13px;
    float: left;
    width: 170px;
    cursor:default;
}

.file_tree {
    width: 923px;
    height: 300px;
    border: solid 1px #678dad;
    background: #fff;
    overflow: auto;
    padding: 5px;
}

.file_tree_tabs {
    width: 702px;
    height: 250px;
    border: solid 1px #678dad;
    background: #fff;
    overflow: auto;
    padding: 5px;
}

.file_tree_short{
    width: 228px;
    height: 379px;
    border: solid 1px #678dad;
    background: #fff;
    overflow: auto;
    padding: 5px;
}
.box_software{
    width: 240px;
    background: #fff;
}
.software_details{float: left;}
#details_box{
    display:block;
    margin-top:10px;
}
#code{
    float: right;
    width: 692px;
}
#details_head{margin-bottom: 10px;}

#contentInfo{
    width: 926px;
    border: solid 1px #678dad;
    background: #fff;
    overflow: auto;
    padding: 3px;
}

#contentInfo p{
    font-size: 14px;
    margin: 5px;
}

#contentInfo h2, .hight{
    background: #e4e4e4;
    width: 100%;
    height: 25px;
    padding-top:2px;
    text-indent: 5px;
    color: #737373;
    text-shadow: 0px 1px #FFF;
}

.show{
    background: #e4e4e4 url(../images/arrow_up.png) 97% 50% no-repeat;
}

.hide{
    background: #e4e4e4 url(../images/arrow_down.png) 97% 50% no-repeat;
}

.gradient{background-color:#f4f4f4;background:-moz-linear-gradient(#f4f4f4,#ececec);background:-webkit-linear-gradient(#f4f4f4,#ececec);-ms-filter:"progid:DXImageTransform.Microsoft.gradient(startColorstr='#f4f4f4',endColorstr='#ececec')";background:linear-gradient(#f4f4f4,#ececec);}

h2.hight:hover{
    cursor: pointer;
}

.log_content{
    border: solid 1px #4c6172;
    padding: 2px;
}

.log {
    border: none;
    background: #f6f7f8;
    color: #000;
    width: 926px;
    padding: 2px;
    height: 450px;
    resize: both;
    font-size: 13px;
    overflow-y: auto;
    white-space: pre-wrap;
}
.log_btn{border: 1px solid #678dad; border-top:none; height: 22px; width: 654px; margin: 0 40px 10px 40px;
    padding:4px 10px 4px 10px; font-size: 16px; color: #4c6172;}
.log p{white-space: pre-wrap; width:100%}
.log p.info{white-space: pre-wrap; width:98%; font-size: 15px; margin: 5px; color:red;}

.waitting{
    margin-left: 10px;
    display: none;
}

.file_info{
    margin-top:10px;
    background: #e4e4e4;
    padding: 5px 10px 5px;
    box-shadow: 1px 1px 1px #888888;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    color: #737373;
    font-weight: bold;
    text-shadow: 0px 1px #FFF;
    margin-bottom: 9px;
    font-size: 14px;
    cursor:default;
    word-wrap: break-word
}

#check{
    margin-right:5px;
    margin-top:2px;
    display: none;
    float: left;
}

.public_key{
    border: 1px solid #678dad;
    overflow: auto;
    height: 95px;
    padding: 5px;
    background:#fff;
    margin-bottom: 10px;
    color: #3A494F;
    font-size:  12px;
}

.div{
    border-top: 1px solid #678dad;
    height: 1px;
    width: 734px;
    margin: 10px;
    margin-top: 20px;
}
label.header {
    color: #4C6172;
    font-size: 18px;
    font-weight: normal;
}
select {
  -webkit-appearance: button;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  box-shadow: 0px 1px 3px rgba(0, 0, 0, 0.1);
  -webkit-padding-end: 20px;
  -webkit-padding-start: 2px;
  -webkit-user-select: none;
  background: #fff;
  border: 1px solid #678dad;
  color: #000;
  font-size: inherit;
  margin: 0;
  overflow: hidden;
  padding: 4px;
  text-overflow: ellipsis;
  white-space: nowrap;}

a.lshare{
    background: #fff;
    padding: 4px 7px 4px 7px;
    height: 18px;
    font-size: 15px;
    border: solid 1px #678dad;
    color: #4DA0C6;
    text-align:center;
    font-weight:bold;
    cursor:pointer;
}
a.lshare:hover{
    background:#D9D9D9;
    border:solid 1px #73A6FF;
    text-shadow: 0px 1px #F0F1F2;
    color: #666666;
}
a.lshare:focus{
    border:solid 1px #73A6FF;
}
a.no-right-border{border-right:none}
a.no-right-border:hover{border-right:none}
a.no-right-border:focus{border-right:none}
a.lshare img{
    margin: 5px;
}

#error{
    padding: 0px;
    position: absolute;
    top: -2px;
    left:0;
    right: 0;
}

#error > div{
    background: none repeat scroll 0 0 #afcee4;
    border: 1px solid #FFF;
    width:500px;
    margin: 0 auto;
    border-top:none;
    border-radius: 0 0 4px 4px;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    text-align: center;
    position: relative;
    z-index: 170;
}

#error table{
    background: none;
    width: 100%;
    font-weight: normal;
}
#error table, #error th, #error tr, #error td{
    border: none;
    padding:0;
}

#error td{
    margin:2px;
}

#error td.logo{
    width: 36px;
    height: 26px;
}
#error td.b_close{
    width: 30px;
    height:22px;
}
#error p{white-space: pre-wrap; word-wrap: break-word; width: 430px; padding-bottom: 5px;}
.noscroll {
    overflow: hidden;
}
.form{padding:10px; padding-left:20px;}
.form label{display:block; float:left; width:150px; padding-top:10px;}
.form input[type=text] ,.form input[type=password] {float:left; width:190px;margin:5px;}
.hiddendiv {display: none;white-space: pre-wrap;min-height: 18px;font-size: 13px;
  padding:3px;word-wrap: break-word;width:430px; max-height:120px;font-family: 'Helvetica Neue',Tahoma,Helvetica,Arial,sans-serif;}
.list{display: block;padding: 5px;background: #E7E7E7; margin-bottom:7px;}
div.sep{display:block; height:7px;}
.slidebox{padding:10px; }
.alert_message{ background: url(../images/alert.png) center no-repeat; height: 26px;}
.error_message{ background: url(../images/exit.png) center no-repeat; height: 26px;}
.confirm_message{ background: url(../images/confirm.png) center no-repeat; height: 26px;}
.info_message{ background: url(../images/info.png) center no-repeat; height: 26px;}
#error p{ font-size: 13px; color: #4A131F;}
#pClose, .close{background:url(../images/close.png) no-repeat 0px 0px; display:block; width:22px; height:22px; cursor:pointer}
#pClose:hover, .close:hover{background:url(../images/close_hover.png) no-repeat 0px 0px;}
.md5sum {margin:10px; font-size:15px;}
.title{background: #e4e4e4; width: 100%; height: 26px; padding-top:2px; text-indent: 5px; color: #737373; text-shadow: 0px 1px #FFF;}
.menu-box-left{float:left; width: 135px; font-size:14px; background: #e4e4e4; padding:5px 0 5px 5px; margin-top:10px;
    font-size:14px; border-radius: 4px 0 0 4px;}
.menu-box-right{background: #e4e4e4; padding: 5px; float:right; width: 745px; margin-left: -5px;
    margin-top:10px; box-shadow: 1px 1px 1px #888888;}
.menu-box-left ul{margin:0px; list-style:none;}
.menu-box-left li{padding: 2px; padding-left:10px; padding-right:10px; text-shadow: 0px 1px #fff;border-bottom:1px solid #fff;}
.menu-box-left li label, .menu-box-left li input[type=radio] { cursor:pointer}
.menu-box-left li:hover{background:#F0F2F2;}
.menu-box-left li.checked{background:#fff;}
.menu-box-right h2{text-align:center}
/* Bubble pop-up */
.popup {position: absolute; display: none; z-index: 150;}
.popup table, .popup td, .popup th{margin:0; padding:0; background:none; border:0; border-collapse:collapse;}
.popup td.corner {height: 15px;width: 19px;}
.popup td#topleft { background-image: url(../images/bubble-8.png); }
.popup td.top { background-image: url(../images/bubble-7.png);}
.popup td#topright { background-image: url(../images/bubble-6.png); }
.popup td.left { background-image: url(../images/bubble-4.png); }
.popup td.right { background-image: url(../images/bubble-5.png); }
.popup td#bottomleft { background-image: url(../images/bubble-3.png); }
.popup td.bottom { background-image: url(../images/bubble-2.png);}
.popup td.top img { display: block; }
.popup td#bottomright { background-image: url(../images/bubble-1.png); }
.popup-contents {background: #fff; color: #666666;}
.popup a{display: block; font-weight:bold;  color: #4DA0C6; padding-left: 5px; padding-bottom: 5px;}
.popup a:hover{color: #666666;}
.popup ul{margin:0; margin-bottom:10px; padding:0; list-style:none;}
.popup li{border-bottom: 1px dashed #666666; padding:0;}
.popup ul li:last-child{border-bottom:none}
.popup ul li a{padding-bottom:0}
ul.menu li {padding-top:5px; padding-bottom:5px;}
ul.menu{margin-bottom:0;}
.popup-value{display:none;}
textarea.parameter {border: solid 1px #678dad; color: #666666; height:110px;}
.link{color:#fff; font-weight:bold; text-decoration:none}
.link:hover{color: #19485C;}
input[type=radio] {
}

input[type=radio]:checked {
}

input[type=radio]:hover {
    box-shadow: 0px 1px 3px #F0F1F2;
}
/* Login Css region *******/
#login-page{width:429px; height:236px; margin:130px auto 0px; background:url(../images/loginBox.png) no-repeat;
padding:10px; font-size:14px; color:#03406A}
#login-page h2{color:#fff; font-size:26px; font-weight:normal; text-indent:50px;}
.login-content{position:relative;margin:10px; margin-top:30px; margin-bottom:0;}
.login-button{width:140px; margin:0 auto;}
.login-element{float:left; min-width:120px;}
.login-label{padding:5px; font-size:16px;}
.login-input{width:220px;}
.information{display:block; float:left; height:16px; margin-top:10px; margin-left:10px; font-weight:bold}
.account{margin-left:60px;}
