{% extends "layout.html" %}
{% block title %}Your current software folder{% endblock %}
{% block head %}
  {{ super() }}
  <link href="{{ url_for('static', filename='css/jqueryFileTree.css', _external=False) }}" rel="stylesheet" type="text/css" media="screen" />
  <script src="{{ url_for('static', filename='js/jquery/jqueryFileTree.js') }}" type="text/javascript" charset="utf-8"></script>
  <script src="{{ url_for('static', filename='js/scripts/softwareFolder.js') }}" type="text/javascript" charset="utf-8"></script>
  <script src="{{ url_for('static', filename='js/ace/ace.js') }}" type="text/javascript" charset="utf-8"></script>
    <script src="{{ url_for('static', filename='js/ace/theme-crimson_editor.js') }}" type="text/javascript" charset="utf-8"></script>
    <script src="{{ url_for('static', filename='js/ace/mode-buildout.js') }}" type="text/javascript" charset="utf-8"></script>
    <script src="{{ url_for('static', filename='js/ace/mode-python.js') }}" type="text/javascript" charset="utf-8"></script>
    <script src="{{ url_for('static', filename='js/ace/mode-php.js') }}" type="text/javascript" charset="utf-8"></script>
{% endblock %}
{% block body %}

<form action="" method=post>
<input type="hidden" name="project" id="project" value="{{project}}" />
<input type="hidden" name="workdir" id="workdir" value="{{workDir}}" />
<input type="hidden" name="subfolder" id="subfolder" value="" />
<div id="software_folder">
  <div class="software_details">
    <a href="#" id="switch" class="lshare no-right-border" style="float:left">Switch to Project</a>
    <a href="#"  id="clearselect" class="lshare no-right-border" style="float:left">Reset</a>
    <a href="#"  id="save" class="lshare" style="float:left">Save</a>
    <div class="clear"></div>
    <div id="details_box">
  	  <div id="fileTree" class="file_tree_short" title="Double click to edit selected file..."></div>
      <div id="fileTreeFull" style='display:none' class="file_tree_short" title="Double click to edit selected file..."></div>
    	<div class="box_software">
    	    <input type="text" name="file" id="file" size='12' value="Name here..." />
    	    &nbsp;<select name="type" id="type">
    	    <option value="file">file</option>
    	    <option value="folder">folder</option>
    	    </select>
    	    &nbsp;<input type="submit" name="add" id ="add" value="Add" class="button"/>
    	</div>
    </div>
  </div>
  <div id="code">
  <h2 class='title'>
    <a style="display:none" id='option' href='#' rel='tooltip' title='Show more option'>[Current file]</a><span id="edit_info">No file in editor</span>
    <span id="edit_status"></span>
  </h2>
  <div class="main_content">
<pre id="editor">

</pre>
            </div>
	    <!--<input type=submit value="Save" id="save" class="button">-->
	</div>

</div>
<div class="clear"></div>
<div id="file_info" class="file_info"><span id="info"></span></div>
<br/>
</form>
<div id="tooltip-option" style="display:none">
  <span class="list first-list">MD5 SUM for the current file</span>
    <a id='getmd5' href="#">Get or Update md5sum</a>
    <div class="sep"></div>
    <span class="list">Add Project to Develop</span>
    <ul id="plist">
    {% for name in projectList%}
      <li><input type="checkbox" name="develop" value="{{name}}" id="{{name}}">
      <label>{{name}}</label></li>
    {% endfor %}
    </ul>
    <a href="#" id="adddevelop" class="lshare">Add to profile</a>
</div>
{% endblock %}
